==> pencil2d_0.6.3.orig.tar.gz: pencil-0.6.3/README.md <==

[![Build Status](https://travis-ci.org/pencil2d/pencil.svg?branch=master)](https://travis-ci.org/pencil2d/pencil)
[![Build status](https://ci.appveyor.com/api/projects/status/65p3ccmohnkmim4x?svg=true)](https://ci.appveyor.com/project/chchwy/pencil2d)

# Pencil2D Animation

**Pencil2D** is an animation/drawing software for Windows, macOS, Linux, and FreeBSD. It lets you create traditional hand-drawn animation (cartoon) using both bitmap and vector graphics. Pencil2D is free and open source.

Pencil2D Website: <https://www.pencil2d.org/>

## Download ###

### Pencil2D 0.6.2 (26 September 2018)

[What's new?](https://www.pencil2d.org/2018/09/maintenance-release-0.6.2.html)

| Windows 64 bit   | Windows 32 bit    | Mac             | Linux             |
| :--------------: | :---------------: | :-------------: | :---------------: |
| [Download][w64]  | [Download][w32]   | [Download][mac] | [Download][lnx]   |

[w64]: https://github.com/pencil2d/pencil/releases/download/v0.6.2/pencil2d-win64-0.6.2.zip
[w32]: https://github.com/pencil2d/pencil/releases/download/v0.6.2/pencil2d-win32-0.6.2.zip
[mac]: https://github.com/pencil2d/pencil/releases/download/v0.6.2/pencil2d-mac-0.6.2.zip
[lnx]: https://github.com/pencil2d/pencil/releases/download/v0.6.2/pencil2d-linux-amd64-0.6.2.AppImage

### Nightly builds

Nightly builds are the bleeding edge versions of Pencil2D, which contains the most recent fixes and features.
The link will direct you to Google Drive, please right-click on a file and select Download. The filename is `pencil2d-OS-year-month-date`.

| Windows 64 bit   | Windows 32 bit    | Mac             | Linux             |
| :--------------: | :---------------: | :-------------: | :---------------: |
| [Download][4]    | [Download][5]     | [Download][6]   | [Download][7]     |

[4]: https://goo.gl/ZaYAtw
[5]: https://goo.gl/cKbtgM
[6]: https://goo.gl/WrAVu9
[7]: https://goo.gl/9TzYRV

## Links

* [Issue Tracker](https://github.com/pencil2d/pencil/issues) - Report bugs or Request features.
* [Transifex](https://www.transifex.com/pencil2d/) - You can help translate Pencil2D, too.
* [Developer Guide](https://github.com/pencil2d/pencil/wiki) - Learn how to compile Pencil2D yourself.

## Source code

* GitHub: <https://github.com/pencil2d/pencil> (Primary)
* Bitbucket: <https://bitbucket.org/chchwy/pencil2d> (Mirror)
* GitLab: <https://gitlab.com/chchwy/pencil2d> (Mirror 2)

==> pencil2d_0.6.4.orig.tar.gz: pencil-0.6.4/README.md <==

[![Build Status](https://travis-ci.org/pencil2d/pencil.svg?branch=master)](https://travis-ci.org/pencil2d/pencil)
[![Build status](https://ci.appveyor.com/api/projects/status/65p3ccmohnkmim4x?svg=true)](https://ci.appveyor.com/project/chchwy/pencil2d)

# Pencil2D Animation

**Pencil2D** is an animation/drawing software for Windows, macOS, Linux, and FreeBSD. It lets you create traditional hand-drawn animation (cartoon) using both bitmap and vector graphics. Pencil2D is free and open source.

Pencil2D Website: <https://www.pencil2d.org/>

## Download ###

### Pencil2D 0.6.4 (5 May 2019)

[What's new?](https://www.pencil2d.org/2019/05/pencil2d-0.6.4-release.html)

| Windows 64 bit   | Windows 32 bit    | Mac             | Linux             |
| :--------------: | :---------------: | :-------------: | :---------------: |
| [Download][w64]  | [Download][w32]   | [Download][mac] | [Download][lnx]   |

[w64]: https://github.com/pencil2d/pencil/releases/download/v0.6.4/pencil2d-win64-0.6.4.zip
[w32]: https://github.com/pencil2d/pencil/releases/download/v0.6.4/pencil2d-win32-0.6.4.zip
[mac]: https://github.com/pencil2d/pencil/releases/download/v0.6.4/pencil2d-mac-0.6.4.zip
[lnx]: https://github.com/pencil2d/pencil/releases/download/v0.6.4/pencil2d-linux-amd64-0.6.4.AppImage

### Nightly Builds

Nightly builds are the bleeding edge versions of Pencil2D, which contains the most recent fixes and features.
The link will direct you to Google Drive, please right-click on a file and select Download. The filename is `pencil2d-OS-year-month-date`.

| Windows 64 bit   | Windows 32 bit    | Mac             | Linux             |
| :--------------: | :---------------: | :-------------: | :---------------: |
| [Download][4]    | [Download][5]     | [Download][6]   | [Download][7]     |

[4]: https://goo.gl/ZaYAtw
[5]: https://goo.gl/cKbtgM
[6]: https://goo.gl/WrAVu9
[7]: https://goo.gl/9TzYRV

## Links

* [Issue Tracker](https://github.com/pencil2d/pencil/issues) - Report bugs or Request features.
* [Transifex](https://www.transifex.com/pencil2d/) - You can help translate Pencil2D, too.
* [Developer Guide](https://github.com/pencil2d/pencil/wiki) - Learn how to compile Pencil2D yourself.

## Source Code

* GitHub: <https://github.com/pencil2d/pencil> (Primary)
* Bitbucket: <https://bitbucket.org/chchwy/pencil2d> (Mirror)
* GitLab: <https://gitlab.com/chchwy/pencil2d> (Mirror 2)
